{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Add snv and indel bam-readcount files to a vcf",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/data_type/DNA",
                                "#main/data_type/RNA"
                            ]
                        }
                    ],
                    "id": "#main/data_type"
                },
                {
                    "type": "File",
                    "id": "#main/indel_bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": "File",
                    "id": "#main/snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vcf_readcount_annotator.cwl",
                    "in": [
                        {
                            "source": "#main/indel_bam_readcount_tsv",
                            "id": "#main/add_indel_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#main/data_type",
                            "id": "#main/add_indel_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_indel_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "indel",
                            "id": "#main/add_indel_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#main/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#main/add_indel_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_indel_bam_readcount_to_vcf"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl",
                    "in": [
                        {
                            "source": "#main/snv_bam_readcount_tsv",
                            "id": "#main/add_snv_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#main/data_type",
                            "id": "#main/add_snv_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_snv_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "snv",
                            "id": "#main/add_snv_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/add_snv_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_snv_bam_readcount_to_vcf"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                    "id": "#main/annotated_bam_readcount_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:4.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#vcf_readcount_annotator.cwl/bam_readcount_tsv"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl/data_type/DNA",
                                "#vcf_readcount_annotator.cwl/data_type/RNA"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#vcf_readcount_annotator.cwl/data_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#vcf_readcount_annotator.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl/variant_type/snv",
                                "#vcf_readcount_annotator.cwl/variant_type/indel",
                                "#vcf_readcount_annotator.cwl/variant_type/all"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#vcf_readcount_annotator.cwl/variant_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_readcount_annotator.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#vcf_readcount_annotator.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
